<?php
/**
 * Weblator Charts.
 *
 * @package   Weblator_Charts_Admin
 * @author    Weblator <daniel.prior@weblator.com>
 * @license   GPL-2.0+
 * @link      http://plugins.weblator.com
 * @copyright 2014 Weblator
 */

class Weblator_Charts_Admin {

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Slug of the plugin screen.
	 *
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_screen_hook_suffix = "toplevel_page_charts";

	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 * settings page and menu.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		$plugin = Weblator_Charts::get_instance();
		$this->plugin_slug = $plugin->get_plugin_slug();

		// Load admin style sheet and JavaScript.
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );

		// Add the options page and menu item.
		add_action( 'admin_menu', array( $this, 'add_plugin_admin_menu' ) );


	}



	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Register and enqueue admin-specific style sheet.
     *
	 * @since     1.0.0
	 *
	 * @return    null    Return early if no settings page is registered.
	 */
	public function enqueue_admin_styles() {

		if ( ! isset( $this->plugin_screen_hook_suffix ) ) {
			return;
		}

		$screen = get_current_screen();
		if ( $this->plugin_screen_hook_suffix == $screen->id ) {
            wp_enqueue_style( $this->plugin_slug .'-bootstrap', plugins_url( 'assets/css/bootstrap.css', __FILE__ ), array(), Weblator_Charts::VERSION );
            wp_enqueue_style( $this->plugin_slug .'-font-awesome', plugins_url( 'assets/css/font-awesome.css', __FILE__ ), array(), Weblator_Charts::VERSION );
            wp_enqueue_style( $this->plugin_slug .'-specturm', plugins_url( 'assets/css/spectrum.css', __FILE__ ), array(), Weblator_Charts::VERSION );
			wp_enqueue_style( $this->plugin_slug .'-admin-styles', plugins_url( 'assets/css/admin.css', __FILE__ ), array(), Weblator_Charts::VERSION );
		}

	}

	/**
	 * Register and enqueue admin-specific JavaScript.
	 *
	 * @since     1.0.0
	 *
	 * @return    null    Return early if no settings page is registered.
	 */
	public function enqueue_admin_scripts() {

		if ( ! isset( $this->plugin_screen_hook_suffix ) ) {
			return;
		}

		$screen = get_current_screen();
		if ( $this->plugin_screen_hook_suffix == $screen->id ) {
            wp_enqueue_script( $this->plugin_slug . '-bootstrap', plugins_url( 'assets/js/bootstrap.min.js', __FILE__ ), array( 'jquery' ), Weblator_Charts::VERSION );
            wp_enqueue_script( $this->plugin_slug . '-mustache', plugins_url( 'assets/js/handlebars-v1.3.0.js', __FILE__ ), array( 'jquery' ), Weblator_Charts::VERSION );
            wp_enqueue_script( $this->plugin_slug . '-specturm', plugins_url( 'assets/js/spectrum.js', __FILE__ ), array( 'jquery' ), Weblator_Charts::VERSION );
			wp_enqueue_script( $this->plugin_slug . '-admin-script', plugins_url( 'assets/js/admin.js', __FILE__ ), array( 'jquery', "jquery-ui-sortable" ), Weblator_Charts::VERSION );
		}

	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	public function add_plugin_admin_menu() {

        if (get_bloginfo("version") < 3.8)
            add_menu_page( 'Charts', 'Charts', 'manage_options', 'charts', array($this, "display_plugin_admin_page"), plugins_url("../assets/poll.png", __FILE__) );
        else
            add_menu_page( 'Charts', 'Charts', 'manage_options', 'charts', array($this, "display_plugin_admin_page"), "dashicons-chart-area");


    }

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_admin_page() {

        global $wpdb;


        if (isset($_GET["action"])){

            $poll = null;
            if (isset($_GET["edit_chart"])){

                $poll = $wpdb->get_row(
                    $wpdb->prepare("
                        SELECT * FROM " . WEBLATOR_CHARTS_PREFIX . "charts WHERE id = %d
                    ", $_GET["edit_chart"])
                );

                $options = $wpdb->get_results(
                  $wpdb->prepare("
                    SELECT * FROM " . WEBLATOR_CHARTS_PREFIX . "chart_options WHERE chart_id = %d AND option_deleted_date IS NULL ORDER BY option_order ASC
                  ", $_GET["edit_chart"])
                );

            }

            include_once('views/view.php');

        }else {

            include_once( 'views/admin.php' );

        }

	}


}
